@@ -4,8 +4,11 @@
 
 Napi::Value SetDebugLevel(const Napi::CallbackInfo& info);
 Napi::Value GetDeviceList(const Napi::CallbackInfo& info);
+Napi::Value GetLibusbCapability(const Napi::CallbackInfo& info);
 Napi::Value EnableHotplugEvents(const Napi::CallbackInfo& info);
 Napi::Value DisableHotplugEvents(const Napi::CallbackInfo& info);
+Napi::Value RefHotplugEvents(const Napi::CallbackInfo& info);
+Napi::Value UnrefHotplugEvents(const Napi::CallbackInfo& info);
 void initConstants(Napi::Object target);
 
 libusb_context* usb_context;
@@ -16,6 +19,7 @@ struct HotPlug {
 
 #ifdef USE_POLL
 #include <poll.h>
+#include <uv.h>
 #include <sys/time.h>
 
 std::map<int, uv_poll_t*> pollByFD;
@@ -94,8 +98,11 @@ Napi::Object Init(Napi::Env env, Napi::Object exports) {
 
 	exports.Set("setDebugLevel", Napi::Function::New(env, SetDebugLevel));
 	exports.Set("getDeviceList", Napi::Function::New(env, GetDeviceList));
+	exports.Set("_getLibusbCapability", Napi::Function::New(env, GetLibusbCapability));
 	exports.Set("_enableHotplugEvents", Napi::Function::New(env, EnableHotplugEvents));
 	exports.Set("_disableHotplugEvents", Napi::Function::New(env, DisableHotplugEvents));
+	exports.Set("refHotplugEvents", Napi::Function::New(env, RefHotplugEvents));
+	exports.Set("unrefHotplugEvents", Napi::Function::New(env, UnrefHotplugEvents));
 	return exports;
 }
 
@@ -128,6 +135,17 @@ Napi::Value GetDeviceList(const Napi::CallbackInfo& info) {
 	return arr;
 }
 
+Napi::Value GetLibusbCapability(const Napi::CallbackInfo& info) {
+	Napi::Env env = info.Env();
+
+	if (info.Length() != 1 || !info[0].IsNumber()) {
+		THROW_BAD_ARGS("Usb::GetLibusbCapability argument is invalid!")
+	}
+
+	int res = libusb_has_capability(info[0].As<Napi::Number>().Int32Value());
+	return Napi::Number::New(env, res);
+}
+
 Napi::ObjectReference hotplugThis;
 
 void handleHotplug(HotPlug* info){
@@ -199,10 +217,27 @@ Napi::Value DisableHotplugEvents(const Napi::CallbackInfo& info) {
 	return env.Undefined();
 }
 
+Napi::Value RefHotplugEvents(const Napi::CallbackInfo& info) {
+	Napi::Env env = info.Env();
+	Napi::HandleScope scope(env);
+	if (hotplugEnabled) {
+		hotplugQueue.ref(env);
+	}
+	return env.Undefined();
+}
+
+Napi::Value UnrefHotplugEvents(const Napi::CallbackInfo& info) {
+	Napi::Env env = info.Env();
+	Napi::HandleScope scope(env);
+	if (hotplugEnabled) {
+		hotplugQueue.unref(env);
+	}
+	return env.Undefined();
+}
+
 #define DEFINE_CONSTANT(OBJ, VALUE) \
 	OBJ.DefineProperty(Napi::PropertyDescriptor::Value(#VALUE, Napi::Number::New(OBJ.Env(), VALUE), static_cast<napi_property_attributes>(napi_enumerable | napi_configurable)));
 
-
 void initConstants(Napi::Object target){
 	DEFINE_CONSTANT(target, LIBUSB_CLASS_PER_INTERFACE);
 	DEFINE_CONSTANT(target, LIBUSB_CLASS_AUDIO);
@@ -282,6 +317,12 @@ void initConstants(Napi::Object target){
 	DEFINE_CONSTANT(target, LIBUSB_CONTROL_SETUP_SIZE);
 	DEFINE_CONSTANT(target, LIBUSB_DT_BOS_SIZE);
 
+	// libusb_capability
+	DEFINE_CONSTANT(target, LIBUSB_CAP_HAS_CAPABILITY);
+	DEFINE_CONSTANT(target, LIBUSB_CAP_HAS_HOTPLUG);
+	DEFINE_CONSTANT(target, LIBUSB_CAP_HAS_HID_ACCESS);
+	DEFINE_CONSTANT(target, LIBUSB_CAP_SUPPORTS_DETACH_KERNEL_DRIVER);
+
 	// libusb_error
 	// Input/output error
 	DEFINE_CONSTANT(target, LIBUSB_ERROR_IO);
